@@ -5,7 +5,7 @@ from django.utils import timezone
 from tracking.models import Visitor, Pageview
 from tracking.utils import get_ip_address
 from tracking.settings import (TRACK_AJAX_REQUESTS,
-    TRACK_ANONYMOUS_USERS, TRACK_PAGEVIEWS, TRACK_IGNORE_URLS)
+    TRACK_ANONYMOUS_USERS, TRACK_PAGEVIEWS, TRACK_IGNORE_URLS, TRACK_IGNORE_STATUS_CODES)
 
 TRACK_IGNORE_URLS = map(lambda x: re.compile(x), TRACK_IGNORE_URLS)
 
@@ -21,6 +21,10 @@ class VisitorTrackingMiddleware(object):
         if request.is_ajax() and not TRACK_AJAX_REQUESTS:
             return response
 
+        # Do not track if HTTP HttpResponse status_code blacklisted
+        if response.status_code in TRACK_IGNORE_STATUS_CODES:
+            return response
+
         # If dealing with a non-authenticated user, we still should track the
         # session since if authentication happens, the `session_key` carries
         # over, thus having a more accurate start time of session
@@ -75,7 +79,8 @@ class VisitorTrackingMiddleware(object):
                 if url.match(path):
                     break
             else:
-                pageview = Pageview(visitor=visitor, url=request.path, view_time=now)
+                pageview = Pageview(visitor=visitor, url=request.path,
+                    view_time=now, method=request.method)
                 pageview.save()
 
         return response
